| define.links | R Documentation |
An interactive function to define which landmarks should be linked to aid visualization.
define.links(spec, ptsize = 1, links = NULL)
spec |
Name of specimen, as an object matrix containing 2D or 3D landmark coordinates |
ptsize |
Numeric Size to plot the landmarks |
links |
Optional An existing links matrix to add on to |
Function takes a matrix of digitized landmark coordinates (e.g. from mshape) and
allows the user to define pairs of landmarks to be linked, for visualization purposes. The output is a matrix
to be used by plotAllSpecimens & plotRefToTarget option 'links='.
Note to RStudio users: if the 'zoom' of your RStudio window is set to something other than 100 sometimes the function can fail to identify the selected points ('warning: no point within 0.25 inches'). In these cases, set your zoom to 100
In the plot window select two landmarks that will be linked. In the console, the user will be prompted to continue linking landmarks to build the wireframe or end the session (typing y or n respectively). For 2D data in plot window, use LEFT mouse button to select landmarks.
Starting with geomorph version 4.1, interactive module selection in 3D is no longer supported, as RGL is not supported under MacOS Tahoe. Only AUTO mode is available.
Function returns a matrix of which landmarks will be links
to be used by plotAllSpecimens & plotRefToTarget option 'links='.
Dean Adams and Emma Sherratt
plotAllSpecimens
plotRefToTarget
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.