Learn R Programming

geomorph (version 3.3.1)

plotGMPhyloMorphoSpace: Deprecated functions in geomorph

Description

The following function has been deprecated in geomorph

Function plots a phylogenetic tree and a set of Procrustes shape variables in tangent space

Notes for geomorph 3.3.0 and subsequent versions

This function is defunct and replaced with gm.prcomp. The functions, summary.gm.prcomp, plot.gm.prcomp, and picknplot.shape allow summaries, ammendable plots, and warpgrids, for points anywhere in a plot, respectively, can be used to accomplish any task of plotGMPhyloMorphospace, with greater flexibility.

Usage

plotGMPhyloMorphoSpace()

plotGMPhyloMorphoSpace()

Arguments

Details

This function has been deprecated. Use gm.prcomp instead, along with summary.gm.prcomp and plot.gm.prcomp. Examples are provided in the vignette, geomorph.PCA.