read.morphologika(file, plot = FALSE)list.filesdefine.sliders.2d or
define.sliders.3d. Landmark coordinates and
specimen information may then be used to conduct GPA using
gpagen,
If the Morphologika headers "[labels]" and "[labelvalues]"
are present, then a data matrix containing all individual
specimen information is returned. If "[labels]" and
"[labelvalues]" are not present in the file, then only
landmark coordinates are returned.list.files