Function takes a matrix of digitized landmark coordinates, such as made by digitize2d,
and helps user choose which landmarks will be treated as "sliders" in Generalized Procrustes analysis
gpagen. This type of semilandmark "slides" along curves lacking known landmarks
(see Bookstein 1997 for algorithm details).
Each sliding semilandmark ("sliders") will slide between two designated points, along a line
tangent to the specified curvature.
Defining landmarks is an interactive procedure (see below for 2D routines). The procedure is overlapping.
For example: there are 5 landmarks (1:5), 1 and 5 are landmarks and 2,3,4 are sliders,
the user must select '1' '2' '3', and then '2' '3' '4', and then '3' '4' '5'.
Selection in 2D
Choosing which landmarks will be sliders involves landmark selection using a mouse in the plot window.
To define the sliders, for each sliding landmark along the curve in the format 'before-slider-after',
using the LEFT mouse button (or regular button for Mac users), click on the hollow circle to choose the landmark
in the following order:
Click to choose the first landmark between which semi-landmark will "slide",
Click to choose sliding landmark,
Click to choose the last landmark between which semi-landmark will "slide",
Selected landmarks will be filled in and lines are drawn connecting the three landmarks,
and will highlight the sliding semilandmark in red and the flanking landmarks in blue.
Notes for geomorph 4.1
Starting with geomorph version 4.1, interactive module selection in 3D is no longer
supported, as RGL is not supported under MacOS Tahoe. Only AUTO mode is available.
AUTO mode
The input 'landmarks' can be simply a vector of numbers corresponding to the "sliders" (semilandmarks) in the order they appear along a curve on the specimen. This can be made by c() or seq() or any other reasonable method.
If the sliders form a closed curve, then the function assumes that the first and last landmarks in the 'landmarks' vector are THE SAME are fixed (not sliders). e.g. if landmark 1 is a fixed landmark, and 2, 3 and 4 are semilandmarks, then sliders = c(1,2,3,4,1).